BP???
#####

.. Please refer to BP000 for detailed instructions on how to write a
   BluePrint (and remove this comment from your final document).

:Number: BP???
:Title:
:Author: Your Name <you@domain>
:Discussions-To: avocado-devel@redhat.com
:Reviewers:
:Created:
:Type:
:Status:

.. contents:: Table of Contents

TL;DR
*****

Short summary of the contents of this blueprint.

Motivation
**********

Why is this needed? Current problems and benefits of the proposed
solution.

Specification
*************

How is this going to be implemented?  Can contain pseudo-code or
architectural descriptions.

Topic 1
=======

Topic 1 description.

Sub-topic 1
-----------

Sub-topic 1 description.

Topic 2
=======

Topic 2 description.

Sub-topic 2
------------

Sub-topic 1 description.

Backwards Compatibility
***********************

How will this break users of previous versions?  Users with tests
using older APIs?  External plugins such as Avocado-VT?

Security Implications
*********************

Do you have any concerns about security with your proposed solution
and what are they?  If there's functionality that is insecure but
highly convenient, consider how to make it "opt-in", disabled by
default.

How to Teach This
*****************

What is the best way to inform our devs and users about your new
feature/solution?  Consider both "how-to" and reference style
documentation, and if appropriate, examples (under ``examples/``)
using the feature.

Related Issues
**************

Here a list of all issues related to this blueprint:

#.

References
**********

[1] - Reference 1

[2] - Reference 2
